from abjad import *


def test_instrumenttools_ContrabassFlute___init___01( ):

    contrabass_flute = instrumenttools.ContrabassFlute( )

    assert isinstance(contrabass_flute, instrumenttools.ContrabassFlute)
