from abjad import *


def test_instrumenttools_Contrabassoon___init___01( ):

    contrabassoon = instrumenttools.Contrabassoon( )

    assert isinstance(contrabassoon, instrumenttools.Contrabassoon)
